pub struct Camera {}Fields
tgt_focus: Vec3<f32>focus: Vec3<f32>tgt_ori: Vec3<f32>ori: Vec3<f32>tgt_dist: f32dist: f32tgt_fov: f32fov: f32tgt_fixate: f32fixate: f32aspect: f32mode: CameraModelast_time: Option<f64>dependents: Dependentsfrustum: Frustum<f32>Implementations
Sourceimpl Camera
impl Camera
Sourcepub fn new(aspect: f32, mode: CameraMode) -> Self
pub fn new(aspect: f32, mode: CameraMode) -> Self
Create a new Camera with default parameters.
Sourcepub fn compute_dependents(&mut self, terrain: &TerrainGrid)
pub fn compute_dependents(&mut self, terrain: &TerrainGrid)
Compute the transformation matrices (view matrix and projection matrix) and position of the camera.
Sourcepub fn compute_dependents_full<V: ReadVol>(
&mut self,
terrain: &V,
is_transparent: fn(&V::Vox) -> bool,
)
pub fn compute_dependents_full<V: ReadVol>( &mut self, terrain: &V, is_transparent: fn(&V::Vox) -> bool, )
The is_fluid argument should return true for transparent voxels.
fn compute_dependents_near<V: ReadVol>( &mut self, terrain: &V, is_transparent: fn(&V::Vox) -> bool, )
fn compute_dependents_far<V: ReadVol>( &mut self, terrain: &V, is_transparent: fn(&V::Vox) -> bool, )
fn compute_dependents_helper(&self, dist: f32) -> Dependents
fn compute_frustum(&mut self, dependents: &Dependents) -> Frustum<f32>
pub fn frustum(&self) -> &Frustum<f32>
pub fn dependents(&self) -> Dependents
Sourcepub fn rotate_by(&mut self, delta: Vec3<f32>)
pub fn rotate_by(&mut self, delta: Vec3<f32>)
Rotate the camera about its focus by the given delta, limiting the input accordingly.
Sourcepub fn set_orientation(&mut self, ori: Vec3<f32>)
pub fn set_orientation(&mut self, ori: Vec3<f32>)
Set the orientation of the camera about its focus.
Sourcepub fn set_orientation_instant(&mut self, ori: Vec3<f32>)
pub fn set_orientation_instant(&mut self, ori: Vec3<f32>)
Set the orientation of the camera about its focus without lerping.
Sourcepub fn zoom_by(&mut self, delta: f32, cap: Option<f32>)
pub fn zoom_by(&mut self, delta: f32, cap: Option<f32>)
Zoom the camera by the given delta, limiting the input accordingly.
Sourcepub fn zoom_switch(&mut self, delta: f32, cap: f32, scale: f32)
pub fn zoom_switch(&mut self, delta: f32, cap: f32, scale: f32)
Zoom with the ability to switch between first and third-person mode.
Note that cap > 18237958000000.0 can cause panic due to float overflow
Sourcepub fn get_distance(&self) -> f32
pub fn get_distance(&self) -> f32
Get the distance of the camera from the focus
Sourcepub fn set_distance(&mut self, dist: f32)
pub fn set_distance(&mut self, dist: f32)
Set the distance of the camera from the focus (i.e., zoom).
pub fn update(&mut self, time: f64, dt: f32, smoothing_enabled: bool)
pub fn lerp_toward(&mut self, tgt_ori: Vec3<f32>, dt: f32, rate: f32)
pub fn interp_time(&self) -> f32
Sourcepub fn get_focus_pos(&self) -> Vec3<f32>
pub fn get_focus_pos(&self) -> Vec3<f32>
Get the focus position of the camera.
Sourcepub fn set_focus_pos(&mut self, focus: Vec3<f32>)
pub fn set_focus_pos(&mut self, focus: Vec3<f32>)
Set the focus position of the camera.
Sourcepub fn force_focus_pos(&mut self, focus: Vec3<f32>)
pub fn force_focus_pos(&mut self, focus: Vec3<f32>)
Set the focus position of the camera, without lerping.
Sourcepub fn force_xy_focus_pos(&mut self, focus: Vec3<f32>)
pub fn force_xy_focus_pos(&mut self, focus: Vec3<f32>)
Set the focus position of the camera, without lerping.
Sourcepub fn get_aspect_ratio(&self) -> f32
pub fn get_aspect_ratio(&self) -> f32
Get the aspect ratio of the camera.
Sourcepub fn set_aspect_ratio(&mut self, aspect: f32)
pub fn set_aspect_ratio(&mut self, aspect: f32)
Set the aspect ratio of the camera.
Sourcepub fn get_orientation(&self) -> Vec3<f32>
pub fn get_orientation(&self) -> Vec3<f32>
Get the orientation of the camera.
Sourcepub fn get_tgt_orientation(&self) -> Vec3<f32>
pub fn get_tgt_orientation(&self) -> Vec3<f32>
Get the orientation that the camera is moving toward.
Sourcepub fn get_effective_fov(&self) -> f32
pub fn get_effective_fov(&self) -> f32
Get the field of view of the camera in radians, taking into account fixation.
Sourcepub fn set_fixate(&mut self, fixate: f32)
pub fn set_fixate(&mut self, fixate: f32)
Set the ‘fixation’ proportion, allowing the camera to focus in with precise aiming. Fixation is applied on top of the regular FoV.
Sourcepub fn set_fov_deg(&mut self, fov: u16)
pub fn set_fov_deg(&mut self, fov: u16)
Set the FOV in degrees
Sourcepub fn set_mode(&mut self, mode: CameraMode)
pub fn set_mode(&mut self, mode: CameraMode)
Set the mode of the camera.
Sourcepub fn get_mode(&self) -> CameraMode
pub fn get_mode(&self) -> CameraMode
Get the mode of the camera
Sourcepub fn next_mode(&mut self, is_admin: bool, has_target: bool)
pub fn next_mode(&mut self, is_admin: bool, has_target: bool)
Cycle the camera to its next valid mode. If is_admin is false then only modes which are accessible without admin access will be cycled to.
Sourcepub fn forward(&self) -> Vec3<f32>
pub fn forward(&self) -> Vec3<f32>
Return a unit vector in the forward direction for the current camera orientation
Sourcepub fn right(&self) -> Vec3<f32>
pub fn right(&self) -> Vec3<f32>
Return a unit vector in the right direction for the current camera orientation
Sourcepub fn forward_xy(&self) -> Vec2<f32>
pub fn forward_xy(&self) -> Vec2<f32>
Return a unit vector in the forward direction on the XY plane for the current camera orientation
Sourcepub fn right_xy(&self) -> Vec2<f32>
pub fn right_xy(&self) -> Vec2<f32>
Return a unit vector in the right direction on the XY plane for the current camera orientation
pub fn get_pos_with_focus(&self) -> Vec3<f32>